@@ -1112,6 +1112,10 @@ int WRAP_MKNOD MKNOD_ARG(int ver UNUSED,
   if(r)
     return -1;
 
+  /* empty file type means regular file */
+  if(!(mode & S_IFMT))
+    mode |= S_IFREG;
+
   st.st_mode= mode & ~old_mask;
   st.st_rdev= XMKNOD_FRTH_ARG dev;
 
@@ -1152,6 +1156,10 @@ int WRAP_MKNODAT MKNODAT_ARG(int ver UNUSED,
   if(r)
     return -1;
 
+  /* empty file type means regular file */
+  if(!(mode & S_IFMT))
+    mode |= S_IFREG;
+
   st.st_mode= mode & ~old_mask;
   st.st_rdev= XMKNODAT_FIFTH_ARG dev;
 
